//******************************************************************
//* DIGILENT JOYSTICK DRIVER
//* LAST UPDATED 11/15/2009
//* FIRMWARE BY FRED EADY FOR SERVO MAGAZINE
//* CHANGES/ADDITIONS
//******************************************************************
//* THIS CODE WRITTEN AND COMPILED USING MICROCHIP C32 V1.10

#include <p32xxxx.h>
#include <plib.h>
#include "stdtypes.h"

//******************************************************************
//* FUNCTION PROTOTYPES
//******************************************************************
void init(void);

//******************************************************************
//* CONFIGURATION FUSE SETTINGS
//******************************************************************
#pragma config ICESEL   = ICS_PGx2		// ICE/ICD Comm Channel Select
#pragma config BWP      = OFF			// Boot Flash Write Protect
#pragma config CP       = OFF			// Code Protect
#pragma config FNOSC    = PRIPLL		// Oscillator Selection
#pragma config FSOSCEN  = OFF			// Secondary Oscillator Enable
#pragma config IESO     = OFF			// Internal/External Switch-over
#pragma config POSCMOD  = HS			// Primary Oscillator
#pragma config OSCIOFNC = OFF			// CLKO Enable
#pragma config FPBDIV   = DIV_8			// Peripheral Clock divisor
#pragma config FCKSM    = CSDCMD		// Clock Switching & Fail Safe Clock Monitor
#pragma config WDTPS    = PS1			// Watchdog Timer Postscale
#pragma config FWDTEN   = OFF			// Watchdog Timer 
#pragma config FPLLIDIV = DIV_2			// PLL Input Divider
#pragma config FPLLMUL  = MUL_16		// PLL Multiplier
#pragma config UPLLIDIV = DIV_2			// USB PLL Input Divider
#pragma config UPLLEN   = OFF			// USB PLL Enabled
#pragma config FPLLODIV = DIV_1			// PLL Output Divider
#pragma config PWP      = OFF			// Program Flash Write Protect
#pragma config DEBUG    = OFF			// Debugger Enable/Disable

//******************************************************************
//* sp -> SPI reference
//* p  -> I/O pin reference
//* m  -> macro reference
//* b  -> bit reference
//******************************************************************

BYTE spData;
BYTE spDataIN[5];
BYTE spIndex,x;

#define pjoystick		9				//slave select at RD9 of MASTER
#define mjoystickOFF	PORTDSET = (1 << pjoystick);
#define mjoystickON		PORTDCLR = (1 << pjoystick);


void init(void)
{
	CloseSPI1();
	x = 0x83;
	TRISDCLR = (1 << pjoystick);		//RD9 is output pin
	spData = ReadSPI1();				//clear SPI receive buffer
	//mSpiChnSetBrg(1,8);					//500KHz SPI clock
	mSpiChnClrRovIntFlag(1);			//clear SPIROV
	
	OpenSPI1(MASTER_ENABLE_ON,SPI_ENABLE);
}

int main(void) 
{
	init();
	do{
	for(spIndex = 0; spIndex < 5; ++spIndex)
	{
		if(!TxBufFullSPI1())
		{
			WriteSPI1(x);
		}
		spDataIN[spIndex] = getcSPI1();
	}
	mjoystickOFF;
	//++x;								//uncomment for debugging
	//if(x > 0x83)						//uncomment for debugging
	
	if(++x > 0x83)						//comment out to debug
		x = 0x80;
	mjoystickON;
	
}while(1);
}
